"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepareParams = prepareParams;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireWildcard(require("react"));

var _server = require("react-dom/server");

var _LocaleProvider = _interopRequireWildcard(require("./LocaleProvider"));

var _Namespace = require("./Namespace");

function prepareParams(params, localeProvider) {
  const newParams = {};
  let changed = false;
  Object.keys(params).forEach(key => {
    const value = params[key];
    const isReactElement = (0, _react.isValidElement)(value);

    if (!isReactElement) {
      newParams[key] = value;
    } else {
      changed = true;
      const _localeProvider$props = localeProvider.props,
            {
        children,
        locale
      } = _localeProvider$props,
            rest = (0, _objectWithoutProperties2.default)(_localeProvider$props, ["children", "locale"]);
      newParams[key] = (0, _server.renderToStaticMarkup)(_react.default.createElement(_LocaleProvider.default, rest, value));
    }
  });
  return changed ? newParams : params;
}

class Translate extends _react.Component {
  getPath() {
    const {
      path,
      $namespace
    } = this.props;

    if (!$namespace) {
      return path;
    }

    const parentPath = $namespace.getPath();

    if (!parentPath) {
      return path;
    }

    return `${parentPath}.${path}`;
  }

  render() {
    const _this$props = this.props,
          {
      path,
      $namespace,
      $localeProvider,
      defaultValue,
      params,
      children,
      html
    } = _this$props,
          rest = (0, _objectWithoutProperties2.default)(_this$props, ["path", "$namespace", "$localeProvider", "defaultValue", "params", "children", "html"]);
    const updatedDefaultValue = !defaultValue && typeof children !== 'function' ? children : defaultValue;
    const updatedParams = prepareParams(params || rest, $localeProvider);
    const text = $localeProvider.get(this.getPath(), updatedParams, updatedDefaultValue);

    if (typeof children === 'function') {
      return children(text);
    }

    if (html) {
      return _react.default.createElement("span", {
        dangerouslySetInnerHTML: {
          __html: text
        }
      });
    }

    return text;
  }

}

(0, _defineProperty2.default)(Translate, "defaultProps", {
  defaultValue: undefined,
  description: undefined,
  params: undefined,
  children: undefined,
  $namespace: undefined,
  html: false
});

var _default = (0, _react.forwardRef)((props, ref) => _react.default.createElement(_LocaleProvider.LocaleProviderConsumer, null, ({
  localeProvider
}) => _react.default.createElement(_Namespace.NamespaceConsumer, null, ({
  namespace
}) => _react.default.createElement(Translate, (0, _extends2.default)({}, props, {
  $localeProvider: localeProvider,
  $namespace: namespace,
  ref: ref
})))));

exports.default = _default;
//# sourceMappingURL=Translate.js.map