import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { forwardRef, isValidElement, Component } from 'react';
import { renderToStaticMarkup } from 'react-dom/server';
import LocaleProvider, { LocaleProviderConsumer } from './LocaleProvider';
import { NamespaceConsumer } from './Namespace';
export function prepareParams(params, localeProvider) {
  const newParams = {};
  let changed = false;
  Object.keys(params).forEach(key => {
    const value = params[key];
    const isReactElement = isValidElement(value);

    if (!isReactElement) {
      newParams[key] = value;
    } else {
      changed = true;

      const _localeProvider$props = localeProvider.props,
            {
        children,
        locale
      } = _localeProvider$props,
            rest = _objectWithoutProperties(_localeProvider$props, ["children", "locale"]);

      newParams[key] = renderToStaticMarkup(React.createElement(LocaleProvider, rest, value));
    }
  });
  return changed ? newParams : params;
}

class Translate extends Component {
  getPath() {
    const {
      path,
      $namespace
    } = this.props;

    if (!$namespace) {
      return path;
    }

    const parentPath = $namespace.getPath();

    if (!parentPath) {
      return path;
    }

    return `${parentPath}.${path}`;
  }

  render() {
    const _this$props = this.props,
          {
      path,
      $namespace,
      $localeProvider,
      defaultValue,
      params,
      children,
      html
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["path", "$namespace", "$localeProvider", "defaultValue", "params", "children", "html"]);

    const updatedDefaultValue = !defaultValue && typeof children !== 'function' ? children : defaultValue;
    const updatedParams = prepareParams(params || rest, $localeProvider);
    const text = $localeProvider.get(this.getPath(), updatedParams, updatedDefaultValue);

    if (typeof children === 'function') {
      return children(text);
    }

    if (html) {
      return React.createElement("span", {
        dangerouslySetInnerHTML: {
          __html: text
        }
      });
    }

    return text;
  }

}

_defineProperty(Translate, "defaultProps", {
  defaultValue: undefined,
  description: undefined,
  params: undefined,
  children: undefined,
  $namespace: undefined,
  html: false
});

export default forwardRef((props, ref) => React.createElement(LocaleProviderConsumer, null, ({
  localeProvider
}) => React.createElement(NamespaceConsumer, null, ({
  namespace
}) => React.createElement(Translate, _extends({}, props, {
  $localeProvider: localeProvider,
  $namespace: namespace,
  ref: ref
})))));
//# sourceMappingURL=Translate.js.map